package zer01hd.zer10hdbot.archive;

import java.io.File;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;
import java.time.format.DateTimeParseException;

public class ArchiveManager {
	private Path rootArchives;
	private File monthDir;
	private TextFile archive;
	private LocalDateTime textInitDate;
	private LocalDateTime currentDate;
	private DateTimeFormatter dirDateFormat = DateTimeFormatter.ofPattern("yyyy/MM/dd");
	private DateTimeFormatter dirMonthFormat = DateTimeFormatter.ofPattern("yyyy/MM");

	public ArchiveManager() {
		rootArchives = Paths.get("archives");
		setupArchive();
		validateArchive();
	}
	
	public boolean validateArchive() {
		currentDate = LocalDateTime.now();
		if (!dirDateFormat.format(currentDate).equals(dirDateFormat.format(textInitDate))) {
			setupArchive();
		}
		return true;
	}
	
	public TextFile getArchive() {
		return archive;
	}
	
	public void writeToArchive(String string) {
		validateArchive();
		archive.write("" + currentDate.toString()+ " " + string);
	}
	
	public LocalDateTime getCurrentDate() {
		return currentDate;
	}
	
	public LocalDateTime getTextInitDate() {
		return textInitDate;
	}
	
	public void setupArchive() {
		currentDate = LocalDateTime.now();
		monthDir = new File(rootArchives.toFile(), dirMonthFormat.format(currentDate));
		monthDir.mkdirs();
		if (archive != null) {
			archive.closeFile();
		}
		archive = new TextFile(monthDir.toPath(), String.valueOf(currentDate.getDayOfMonth()));
		textInitDate = LocalDateTime.of(Integer.valueOf(monthDir.getParentFile().getName()), Integer.valueOf(monthDir.getName()), Integer.valueOf(archive.getFile().getName().substring(0, archive.getFile().getName().length() - ".txt".length())), 0, 0);
		archive.write("Archive began logging at: " + textInitDate.toString() + "\n");
		archive.flush();
	}
	
	public File obtainArchive(String date) {
		date = date.replace('/', '-');
		date = date.concat("T00:00:00");
		LocalDateTime givenDate;
		try {
			givenDate = LocalDateTime.parse(date);
		} catch (DateTimeParseException e) {
			System.out.println("Error with date. Couldn't retrieve archive.");
			return null;
		}
		File archivedFile = new File(rootArchives.toFile(), dirDateFormat.format(givenDate) + ".txt");
		if (archivedFile.exists()) {
			return archivedFile;
		} else {
			return null;
		}
	}
}
